@@ -6,6 +6,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.conf import global_settings
 from django.conf.urls import include, patterns, url
 from django.utils.module_loading import module_has_submodule
+from django.views.generic.base import RedirectView
 import importlib
 import operator
 
@@ -120,7 +121,7 @@ def merge_dictionaries(current, new, only_defaults=False):
                     changes += 1
         else:
             # If we don't know what to do with it, replace it.
-            if current_value != value:
+            if current_value is not value:
                 current[key] = value
                 LOGGER.debug("Set %r to %r.", key, current[key])
                 changes += 1
@@ -136,7 +137,7 @@ def configure_settings(settings):
 
     while changes:
         changes = 0
-        for app_name in list(settings['INSTALLED_APPS']) + ['django_autoconfig']:
+        for app_name in ['django_autoconfig'] + list(settings['INSTALLED_APPS']):
             if app_name not in settings.get('AUTOCONFIG_DISABLED_APPS', ()):
                 app_module = importlib.import_module(app_name)
             else:
@@ -167,14 +168,20 @@ def configure_settings(settings):
         iterations += 1
     LOGGER.debug("Autoconfiguration took %d iterations.", iterations)
 
-def configure_urls(apps):
+def configure_urls(apps, index_view=None):
     '''
     Configure urls from a list of apps.
     '''
     urlpatterns = patterns('')
 
+    if index_view:
+        urlpatterns += patterns('',
+            url(r'^$', RedirectView.as_view(pattern_name=index_view)),
+        )
+
     for app_name in apps:
-        try:
+        app_module = importlib.import_module(app_name)
+        if module_has_submodule(app_module, 'urls'):
             module = importlib.import_module("%s.urls" % app_name)
             if not hasattr(module, 'urlpatterns'):
                 # Resolver will break if the urls.py file is completely blank.
@@ -186,6 +193,6 @@ def configure_urls(apps):
                     include("%s.urls" % app_name),
                 ),
             )
-        except ImportError:
-            pass
+
+
     return urlpatterns
